@@ -13,7 +13,6 @@ compas
     compas.files
     compas.geometry
     compas.numerical
-    compas.remote
     compas.robots
     compas.rpc
     compas.topology
@@ -35,7 +34,7 @@ __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
 __license__ = 'MIT License'
 __email__ = 'vanmelet@ethz.ch'
 
-__version__ = '0.11.4'
+__version__ = '0.12.4'
 
 
 PY3 = sys.version_info[0] == 3
@@ -71,6 +70,7 @@ try:
 except Exception:
     pass
 
+
 __all__ = [
     'raise_if_windows',
     'raise_if_not_windows',
@@ -245,7 +245,7 @@ def get(filename):
     if os.path.exists(localpath):
         return localpath
     else:
-        return "https://raw.githubusercontent.com/compas-dev/compas/master/data/{}".format(filename)
+        return "https://github.com/compas-dev/compas/raw/master/data/{}".format(filename)
 
 
 def get_bunny(localstorage=None):
