@@ -5,7 +5,7 @@ from __future__ import print_function
 import compas
 
 if not compas.IPY:
-    from .isolines_numpy import *
+    from .isolines_numpy import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
