@@ -2,9 +2,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from compas.files import URDF
 from compas.files import URDFParser
-from compas.geometry import Transformation
 
 from compas.robots.model.geometry import Box
 from compas.robots.model.geometry import Capsule
@@ -50,11 +48,16 @@ class Inertia(object):
 class Inertial(object):
     """Inertial properties of a link.
 
-    Attributes:
-        origin: This is the pose of the inertial reference frame,
-            relative to the link reference frame.
-        mass: Mass of the link.
-        inertia: 3x3 rotational inertia matrix, represented in the inertia frame.
+    Attributes
+    ----------
+    origin:
+        This is the pose of the inertial reference frame,
+        relative to the link reference frame.
+    mass:
+        Mass of the link.
+    inertia:
+        3x3 rotational inertia matrix, represented in the inertia frame.
+
     """
 
     def __init__(self, origin=None, mass=None, inertia=None):
@@ -66,13 +69,20 @@ class Inertial(object):
 class Visual(object):
     """Visual description of a link.
 
-    Attributes:
-        geometry: Shape of the visual element.
-        origin: Reference frame of the visual element with respect
-            to the reference frame of the link.
-        name: Name of the visual element.
-        material: Material of the visual element.
-        attr: Non-standard attributes.
+    Attributes
+    ----------
+    geometry:
+        Shape of the visual element.
+    origin:
+        Reference frame of the visual element with respect
+        to the reference frame of the link.
+    name:
+        Name of the visual element.
+    material:
+        Material of the visual element.
+    attr:
+        Non-standard attributes.
+
     """
 
     def __init__(self, geometry, origin=None, name=None, material=None, **kwargs):
@@ -96,12 +106,18 @@ class Visual(object):
 class Collision(object):
     """Collidable description of a link.
 
-    Attributes:
-        geometry: Shape of the collidable element.
-        origin: Reference frame of the collidable element with respect
-            to the reference frame of the link.
-        name: Name of the collidable element.
-        attr: Non-standard attributes.
+    Attributes
+    ----------
+    geometry:
+        Shape of the collidable element.
+    origin:
+        Reference frame of the collidable element with respect
+        to the reference frame of the link.
+    name:
+        Name of the collidable element.
+    attr:
+        Non-standard attributes.
+
     """
 
     def __init__(self, geometry, origin=None, name=None, **kwargs):
@@ -118,16 +134,26 @@ class Collision(object):
 class Link(object):
     """Link represented as a rigid body with an inertia, visual, and collision features.
 
-    Attributes:
-        name: Name of the link itself.
-        type: Link type. Undocumented in URDF, but used by PR2.
-        visual: Visual properties of the link.
-        collision: Collision properties of the link. This can be different
-            from the visual properties of a link.
-        inertial: Inertial properties of the link.
-        attr: Non-standard attributes.
-        joints: A list of joints that are the link's children
-        parent_joint: The reference to a parent joint if it exists
+    Attributes
+    ----------
+    name:
+        Name of the link itself.
+    type:
+        Link type. Undocumented in URDF, but used by PR2.
+    visual:
+        Visual properties of the link.
+    collision:
+        Collision properties of the link. This can be different
+        from the visual properties of a link.
+    inertial:
+        Inertial properties of the link.
+    attr:
+        Non-standard attributes.
+    joints:
+        A list of joints that are the link's children
+    parent_joint:
+        The reference to a parent joint if it exists
+
     """
 
     def __init__(self, name, type=None, visual=[], collision=[], inertial=None, **kwargs):
@@ -160,3 +186,10 @@ URDFParser.install_parser(Capsule, 'robot/link/visual/geometry/capsule', 'robot/
 URDFParser.install_parser(Material, 'robot/link/visual/material')
 URDFParser.install_parser(Color, 'robot/link/visual/material/color')
 URDFParser.install_parser(Texture, 'robot/link/visual/material/texture')
+
+# ==============================================================================
+# Main
+# ==============================================================================
+
+if __name__ == '__main__':
+    pass
