@@ -14,14 +14,10 @@ compas_blender
     compas_blender.utilities
 
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-from .utilities import *
+from .utilities import *  # noqa: F401 F403
 
 
-__version__ = '0.11.4'
+__version__ = '0.12.4'
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
