@@ -14,11 +14,11 @@ compas_ghpython
     compas_ghpython.utilities
 
 """
-from .utilities import *
-from .helpers import *
+from .utilities import *  # noqa: F401 F403
+from .helpers import *  # noqa: F401 F403
 
 
-__version__ = '0.11.4'
+__version__ = '0.12.4'
 
 
 __all__ = []
