@@ -25,15 +25,15 @@ from __future__ import absolute_import
 
 import os
 import compas._os
-from .utilities import *
+from .utilities import *  # noqa: F401 F403
 
 try:
-    import rhinoscriptsyntax as rs
+    import rhinoscriptsyntax as rs  # noqa: F401
 except ImportError:
     pass
 
 
-__version__ = '0.11.4'
+__version__ = '0.12.4'
 
 
 PURGE_ON_DELETE = True
